package za.company.constraint;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import javax.validation.Constraint;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import javax.validation.Payload;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * This is used particularly in cases where the end user has to accept certain
 * Ts and Cs before he/she can proceed
 *
 * @author Hlulani Mhlongo <hmhlongo@fnb.co.za>
 */
@Target({
    ElementType.FIELD,
    ElementType.ANNOTATION_TYPE,
    ElementType.CONSTRUCTOR,
    ElementType.PARAMETER})
@Retention(RetentionPolicy.RUNTIME)
@Documented
@Constraint(validatedBy = Accepted.AcceptedValidator.class)
public @interface Accepted {

    String message() default "{fol.validation.constraints.Accepted.message}";

    Class<?>[] groups() default {};

    Class<? extends Payload>[] payload() default {};

    class AcceptedValidator implements ConstraintValidator<Accepted, Object> {

        private static final Logger LOG = LoggerFactory.getLogger(AcceptedValidator.class);

        @Override
        public void initialize(Accepted constraintAnnotation) {
        }

        @Override
        public boolean isValid(Object value, ConstraintValidatorContext context) {
            return isValid(value);
        }

        /**
         * This is a function that can be used manually outside the validation
         * framework
         */
        public boolean isValid(Object value) {
            LOG.debug("Accepted Test Value: {}", value);
            return Boolean.valueOf(String.valueOf(value));
        }
    }
}
