package za.company.constraint;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import javax.validation.Constraint;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import javax.validation.Payload;

/**
 *
 * @author Hlulani Mhlongo <hmhlongo@fnb.co.za>
 */
@Documented
@Constraint(validatedBy = Email.EmailValidator.class)
@Target({
    ElementType.FIELD,
    ElementType.ANNOTATION_TYPE,
    ElementType.CONSTRUCTOR,
    ElementType.PARAMETER})
@Retention(RetentionPolicy.RUNTIME)
public @interface Email {

    String message() default "{fol.validation.constraints.Email.message}";

    Class<?>[] groups() default {};

    Class<? extends Payload>[] payload() default {};

    class EmailValidator implements ConstraintValidator<Email, String> {

        @Override
        public void initialize(Email constraintAnnotation) {
        }

        @Override
        public boolean isValid(String value, ConstraintValidatorContext context) {
            return isValid(value);
        }

        /**
         * This is a function that can be used manually outside the validation
         * framework
         */
        public boolean isValid(String value) {

            if (value == null) {
                return false;
            }
            return value.matches("^[\\w.]+@[\\w]+([.]{1}[a-zA-Z]+){1}([.][a-zA-Z]+)?+$");
        }
    }
}
